@@ -8,13 +8,14 @@ use vars qw(@ISA $VERSION);
 use Digest::HMAC_MD5 qw(hmac_md5_hex);
 use strict;
 
-$VERSION = "0.3";
+$VERSION = "0.32";
 
 @ISA = qw(Authen::SASL);
 
 sub init {
   my $self = shift;
   my $opt = shift;
+  $self->SUPER::init($opt);
   $self->{'response'} = defined $opt->{'password'}
                 ? $opt->{'password'}
                 : defined $opt->{'response'}
@@ -28,7 +29,7 @@ sub name { "CRAM-MD5" }
 sub response {
   my $self   = shift;
   my $string = shift;
-  defined $self->{'password'} ? $self->{'password'} : "";
+  defined $self->{'response'} ? $self->{'response'} : "";
 }
 
 sub encode {
