@@ -1,18 +1,18 @@
 BEGIN {
 
-  # Set this to the path to where you have slapd
-  $SLAPD    = $ENV{SLAPD_EXE} || "../../openldap/ldap/servers/slapd/slapd";
+  foreach (qw(my.cfg test.cfg)) {
+    -f and require "$_" and last;
+  }
+
+  undef $SERVER_EXE unless $SERVER_EXE and -x $SERVER_EXE;
 
   # If your host cannot be contacted as localhost, change this
-  $HOST     = 'localhost';
+  $HOST     ||= '127.0.0.1';
 
   # Where to but temporary files while testing
   # the Makefile is setup to delete temp/ when make clean is run
   $TEMPDIR  = "./temp";
 
-  # Do NOT change any values below here
-
-  $CONF_IN  = "./data/slapd-conf.in";
   $TESTDB   = "$TEMPDIR/test-db";
   $CONF     = "$TEMPDIR/conf";
   $PASSWD   = 'secret';
@@ -21,8 +21,25 @@ BEGIN {
   $JAJDN    = "cn=James A Jones 1, ou=Alumni Association, ou=People, o=University of Michigan, c=US";
   $BABSDN   = "cn=Barbara Jensen, ou=Information Technology Division, ou=People, o=University of Michigan, c=US";
   $PORT     = 9009;
-  @LDAPD    = ($SLAPD, '-f',$CONF,'-p',$PORT,qw(-d 1));
 
+  my @server_opts;
+  ($SERVER_TYPE,@server_opts) = split(/\+/, $SERVER_TYPE || 'none');
+
+  if ($SERVER_TYPE eq 'openldap1') {
+    $CONF_IN	  = "./data/slapd-conf.in";
+    @LDAPD	  = ($SERVER_EXE, '-f',$CONF,'-p',$PORT,qw(-d 1));
+    $LDAP_VERSION = 2;
+  }
+  elsif ($SERVER_TYPE eq 'openldap2') {
+    $SSL_PORT = 9010 if grep { $_ eq 'ssl' } @server_opts;
+    $CONF_IN	  = "./data/slapd2-conf.in";
+    my $url = "ldap://${HOST}:$PORT/";
+    $url .= " ldaps://${HOST}:$SSL_PORT/" if $SSL_PORT;
+    @LDAPD	  = ($SERVER_EXE, '-f',$CONF,'-h',$url,qw(-d 1));
+    $LDAP_VERSION = 3;
+  }
+
+  $LDAP_VERSION ||= 2;
   mkdir($TEMPDIR,0777);
   die "$TEMPDIR is not a directory" unless -d $TEMPDIR;
 }
@@ -31,25 +48,32 @@ use Net::LDAP;
 use Net::LDAP::LDIF;
 use File::Path qw(rmtree);
 use File::Basename qw(basename);
-use vars qw($NO_SERVER);
 
 my $pid;
 
 sub start_server {
-  unless (defined($LDAPD[0]) && -x $LDAPD[0]) {
+  my %arg = (version => 2, @_);
+
+  unless ($LDAP_VERSION >= $arg{version}
+	and $LDAPD[0] and -x $LDAPD[0]
+	and (!$arg{ssl} or $SSL_PORT))
+  {
     print "1..0\n";
     exit;
   }
 
-  # Create slapd config file
-  open(CONFI,"<$CONF_IN") or die "$!";
-  open(CONFO,">$CONF") or die "$!";
-  while(<CONFI>) {
-    s/\$(\w+)/${$1}/g;
-    print CONFO;
+  if ($CONF_IN and -f $CONF_IN) {
+    # Create slapd config file
+    open(CONFI,"<$CONF_IN") or die "$!";
+    open(CONFO,">$CONF") or die "$!";
+    while(<CONFI>) {
+      s/\$(\w+)/${$1}/g;
+      s/^TLS/#TLS/ unless $SSL_PORT;
+      print CONFO;
+    }
+    close(CONFI);
+    close(CONFO);
   }
-  close(CONFI);
-  close(CONFO);
 
   rmtree($TESTDB) if ( -d $TESTDB );
   mkdir($TESTDB,0777);
@@ -83,17 +107,28 @@ END {
 }
 
 sub client {
-  Net::LDAP->new($HOST, port => $PORT) or die "$@"
-}
-
-sub server_version {
-  my $ldap = shift or return;
-  my $dse = $ldap->root_dse or return 2;
-  ( sort { $b <=> $a } $dse->get('version'))[0] || 2;
+  my %arg = @_;
+  my $ldap;
+  my $count;
+  local $^W = 0;
+  if ($arg{ssl}) {
+    require Net::LDAPS;
+    until($ldap = Net::LDAPS->new($HOST, port => $SSL_PORT, version => 3)) {
+      die "ldaps://$HOST:$SSL_PORT/ $@" if ++$count > 10;
+      sleep 1;
+    }
+  }
+  else {
+    until($ldap = Net::LDAP->new($HOST, port => $PORT)) {
+      die "ldap://$HOST:$PORT/ $@" if ++$count > 10;
+      sleep 1;
+    }
+  }
+  $ldap;
 }
 
 sub compare_ldif {
-  my($test,$mesg,$test_num,@sort) = @_;
+  my($test,$test_num,$mesg) = splice(@_,0,3);
 
   if ($mesg->code) {
     print $mesg->error,"\n";
@@ -104,7 +139,7 @@ sub compare_ldif {
   }
   print "ok ",$test_num++,"\n";
 
-  my $ldif = Net::LDAP::LDIF->new("$TEMPDIR/${test}-out.ldif","w");
+  my $ldif = Net::LDAP::LDIF->new("$TEMPDIR/${test}-out.ldif","w", lowercase => 1);
   unless ($ldif) {
     print "not ok",$test_num++,"\n";
     print "not ok",$test_num++,"\n";
@@ -112,9 +147,9 @@ sub compare_ldif {
   }
   print "ok ",$test_num++,"\n";
 
-  foreach $entry ($mesg->sorted(@sort)) {
+  foreach $entry (@_) {
     foreach $attr ($entry->attributes) {
-      $entry->delete($attr) if $attr =~ /^(modifiersname|modifytimestamp|creatorsname|createtimestamp)$/;
+      $entry->delete($attr) if $attr =~ /^(modifiersname|modifytimestamp|creatorsname|createtimestamp)$/i;
     }
     $ldif->write($entry);
   }
@@ -136,4 +171,22 @@ sub compare($$) {
   );
 }
 
+sub ldif_populate {
+  my ($ldap, $file, $change) = @_;
+  my $ok = 1;
+
+  my $ldif = Net::LDAP::LDIF->new($file,"r", changetype => $change || 'add')
+	or return;
+
+  while (my $e = $ldif->read_entry) {
+    $mesg = $e->update($ldap);
+    if ($mesg->code) {
+      $ok = 0;
+      Net::LDAP::LDIF->new(qw(- w))->write_entry($e);
+      print "# ",$mesg->code,": ",$mesg->error,"\n";
+    }
+  }
+  $ok;
+}
+
 1;
